summary refs log tree commit diff
path: root/pkgs/tools/filesystems/xfsprogs
diff options
context:
space:
mode:
authoreburimu <urusan80@gmail.com>2018-11-28 12:44:42 +0300
committerJohn Ericson <git@JohnEricson.me>2018-12-02 00:44:25 -0500
commit0b695faa07c8a01da2ffeaee40577dcfdfd98ed8 (patch)
treef3af5365358b1fb56c36fa11c00c7b912ac6b1e8 /pkgs/tools/filesystems/xfsprogs
parentdc8aca448d0570ade231f92272c4453bc9837fc9 (diff)
downloadnixpkgs-0b695faa07c8a01da2ffeaee40577dcfdfd98ed8.tar
nixpkgs-0b695faa07c8a01da2ffeaee40577dcfdfd98ed8.tar.gz
nixpkgs-0b695faa07c8a01da2ffeaee40577dcfdfd98ed8.tar.bz2
nixpkgs-0b695faa07c8a01da2ffeaee40577dcfdfd98ed8.tar.lz
nixpkgs-0b695faa07c8a01da2ffeaee40577dcfdfd98ed8.tar.xz
nixpkgs-0b695faa07c8a01da2ffeaee40577dcfdfd98ed8.tar.zst
nixpkgs-0b695faa07c8a01da2ffeaee40577dcfdfd98ed8.zip
xfsprogs: fix cross compilation
Diffstat (limited to 'pkgs/tools/filesystems/xfsprogs')
-rw-r--r--pkgs/tools/filesystems/xfsprogs/default.nix12
1 files changed, 9 insertions, 3 deletions
diff --git a/pkgs/tools/filesystems/xfsprogs/default.nix b/pkgs/tools/filesystems/xfsprogs/default.nix
index d38e26edec6..0a6cc4f03fd 100644
--- a/pkgs/tools/filesystems/xfsprogs/default.nix
+++ b/pkgs/tools/filesystems/xfsprogs/default.nix
@@ -1,4 +1,6 @@
-{ stdenv, fetchpatch, fetchgit, autoconf, automake, gettext, libtool, readline, utillinux }:
+{ stdenv, fetchpatch, fetchgit, autoconf, automake, gettext, libtool, readline
+, buildPackages, libuuid
+}:
 
 let
   gentooPatch = name: sha256: fetchpatch {
@@ -19,8 +21,12 @@ stdenv.mkDerivation rec {
 
   outputs = [ "bin" "dev" "out" "doc" ];
 
-  nativeBuildInputs = [ autoconf automake libtool gettext ];
-  propagatedBuildInputs = [ utillinux ]; # Dev headers include <uuid/uuid.h>
+  depsBuildBuild = [ buildPackages.stdenv.cc ];
+  nativeBuildInputs = [
+    autoconf automake libtool gettext
+    libuuid # codegen tool uses libuuid
+  ];
+  propagatedBuildInputs = [ libuuid ]; # Dev headers include <uuid/uuid.h>
   buildInputs = [ readline ];
 
   enableParallelBuilding = true;